import { useFormik } from "formik";
import { Button } from "@mui/material";
import { DynamicFields } from "../utils/Fields";
import { validationSchema } from "../utils/Validations";
import PropTypes from 'prop-types';

const DynamicForm = ({ formJson, buttonClick }) => {
    const initialValues = formJson.form_data.reduce((acc, field) => {
        acc[field.key] = field.defaultValue || "";
        return acc;
    }, {});

    const formik = useFormik({
        initialValues,
        validationSchema: validationSchema(formJson),
        onSubmit: buttonClick,
    });

    return (
        <form onSubmit={formik.handleSubmit}>
            {formJson.form_data.map((field) => (
                <DynamicFields key={field.key} formik={formik} field={field} />
            ))}
            <Button type="submit">Submit</Button>
        </form>
    );
};

DynamicForm.propTypes = {
    formJson: PropTypes.any,
    buttonClick: PropTypes.func
};

export default DynamicForm;
